<?php

##################################################################################
#    HOTELDRUID
#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version accepted by Marco Maria Francesco De Santis, which
#    shall act as a proxy as defined in Section 14 of version 3 of the
#    license.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##################################################################################



# files that contain hoteldruid source code
$files_sorgente = array(
'aggiorna.php',
'base.css',
'base.js',
'clienti.php',
'COPYING',
'costanti.php',
'costi.php',
'creaanno.php',
'crea_backup.php',
'creadb.php',
'crea_modelli.php',
'creaprezzi.php',
'crearegole.php',
'dati_relutenti.php',
'disponibilita.php',
'gestione_utenti.php',
'index.html',
'inizio.php',
'interconnessioni.php',
'inventario.php',
'messaggi.php',
'modifica_app.php',
'modifica_cliente.php',
'modifica_contratto.php',
'modifica_costi.php',
'modifica_ospiti.php',
'modifica_prenota.php',
'modifica_var_contr.php',
'mostra_sorgente.php',
'personalizza.php',
'prenota.php',
'privilegi_utenti.php',
'punto_vendita.php',
'README',
'storia_soldi.php',
'tabella2.php',
'tabella3.php',
'tabella.php',
'tab_tariffe.php',
'visualizza_contratto.php',
'visualizza_tabelle.php',
'dati/',
'dati/DATI',
'doc/',
'doc/CHANGELOG',
'doc/README.english',
'doc/README.espagnol',
'doc/README.italiano',
'doc/README.themes',
'doc/README.translation',
'doc/TODO',
'img/',
'img/addbackup.png',
'img/adddocument.png',
'img/addextracost.png',
'img/addinventory.png',
'img/addmonths.png',
'img/addphoto.png',
'img/addroom.png',
'img/adduser.png',
'img/backmenu.png',
'img/backup_mini.png',
'img/backup.png',
'img/button28.gif',
'img/button.gif',
'img/cancel_mini.png',
'img/cancel.png',
'img/cbackup.png',
'img/cclient.png',
'img/ccreditcard.png',
'img/cdocument.png',
'img/cexpenses.png',
'img/cextracost.png',
'img/check_avail.png',
'img/cinventory.png',
'img/client_mini.png',
'img/client.png',
'img/cmonths.png',
'img/configure_mini.png',
'img/configure.png',
'img/cphoto.png',
'img/creditcard_mini.png',
'img/creditcard.png',
'img/creserv.png',
'img/creservs.png',
'img/crespayment.png',
'img/croce.gif',
'img/croom.png',
'img/crule.png',
'img/ctaxes.png',
'img/dir1_des.png',
'img/dir1_sin.png',
'img/dir2_des.png',
'img/dir2_sin.png',
'img/dir3_des.png',
'img/dir3_sin.png',
'img/docbackup.png',
'img/documents_mini.png',
'img/documents.png',
'img/downbackup.png',
'img/edit2_mini.png',
'img/edit_mini.png',
'img/edit.png',
'img/emailsend.png',
'img/emails_mini.png',
'img/expenses.png',
'img/expinc.png',
'img/extracosts_mini.png',
'img/extracosts.png',
'img/favicon.ico',
'img/freccia_destra_marg.png',
'img/freccia_giu_marg.png',
'img/freccia_sinistra_marg.png',
'img/freccia_su_marg.png',
'img/fr_sx_checkin.gif',
'img/fr_sx_rossa.gif',
'img/goarrow_mini.png',
'img/goarrow.png',
'img/goarrow_xmini.png',
'img/goback.png',
'img/guests2.png',
'img/guests.png',
'img/iclient.png',
'img/iexpense.png',
'img/iexpenses.png',
'img/iincome.png',
'img/incomes_mini.png',
'img/incomes.png',
'img/interconn_mini.png',
'img/interconn.png',
'img/inventory_mini.png',
'img/inventory.png',
'img/iprices.png',
'img/ireserv_mini.png',
'img/ireserv.png',
'img/irules.png',
'img/key_mini.png',
'img/key.png',
'img/logo.png',
'img/mclient.png',
'img/menu_mini.png',
'img/menu.png',
'img/messages_mini.png',
'img/messages.png',
'img/minventory.png',
'img/month1_mini.png',
'img/month2_mini.png',
'img/month3_mini.png',
'img/month4_mini.png',
'img/month_mini.png',
'img/month.png',
'img/mprices.png',
'img/mreserv.png',
'img/mreservs.png',
'img/mroom.png',
'img/muser.png',
'img/next.png',
'img/ok.png',
'img/plus_mini.png',
'img/plus.png',
'img/pos_mini.png',
'img/pos.png',
'img/prev.png',
'img/prices_mini.png',
'img/print.png',
'img/rates.png',
'img/resall_mini.png',
'img/resarrivals_mini.png',
'img/rescurrent_mini.png',
'img/resdepartures_mini.png',
'img/resdepcurr_mini.png',
'img/resdocbackup.png',
'img/reservations_mini.png',
'img/reservations.png',
'img/respayments_mini.png',
'img/respayments.png',
'img/restorebackup.png',
'img/rooms_mini.png',
'img/roomsnear.png',
'img/rooms.png',
'img/ruleperiod.png',
'img/rules_mini.png',
'img/rules.png',
'img/search_mini.png',
'img/selected_mini.png',
'img/selected.png',
'img/send.png',
'img/statistics_mini.png',
'img/statistics.png',
'img/stockroom.png',
'img/table.png',
'img/tables_mini.png',
'img/taxes_mini.png',
'img/taxes.png',
'img/taxperiod.png',
'img/upbackup.png',
'img/upload_mini.png',
'img/users_mini.png',
'img/users.png',
'img/website_mini.png',
'img/website.png',
'img/websites.png',
'img/xclient.png',
'img/xdocument.png',
'img/xextracost.png',
'img/xinventory.png',
'img/xprices.png',
'img/xuser.png',

'includes/',
'includes/costanti.php',
'includes/dati_form_prenotazione.php',
'includes/files_sorgente.php',
'includes/foot.php',
'includes/funzioni_aggiorna.php',
'includes/funzioni_anno.php',
'includes/funzioni_appartamenti.php',
'includes/funzioni_backup.php',
'includes/funzioni_clienti.php',
'includes/funzioni_contratti.php',
'includes/funzioni_costi_agg.php',
'includes/funzioni_dati_relutenti.php',
'includes/funzioni_ins_prenota.php',
'includes/funzioni_log.php',
'includes/funzioni_menu.php',
'includes/funzioni_mod_prenota.php',
'includes/funzioni_mysqli.php',
'includes/funzioni_mysql.php',
'includes/funzioni.php',
'includes/funzioni_postgresql.php',
'includes/funzioni_quadro_disp.php',
'includes/funzioni_relutenti.php',
'includes/funzioni_sqlite.php',
'includes/funzioni_tariffe.php',
'includes/funzioni_testo.php',
'includes/head.php',
'includes/.htaccess',
'includes/liberasettimane.php',
'includes/lista_citta.php',
'includes/lista_documentiid.php',
'includes/lista_nazioni.php',
'includes/lista_parentele.php',
'includes/lista_regioni.php',
'includes/hoteld_doc_backup.php',
'includes/sett_gio.php',
'includes/spezzaprenota.php',
'includes/variabili_contratto.php',
'includes/interconnect/',
'includes/interconnect/aggiorna_ic_fork.php',
'includes/interconnect/aggiorna_ic.php',
'includes/lang/',
'includes/lang/en/',
'includes/lang/en/aggiorna.php',
'includes/lang/en/clienti.php',
'includes/lang/en/costi.php',
'includes/lang/en/crea_backup.php',
'includes/lang/en/creadb.php',
'includes/lang/en/crea_modelli.php',
'includes/lang/en/creaprezzi.php',
'includes/lang/en/crearegole.php',
'includes/lang/en/disponibilita.php',
'includes/lang/en/foot.php',
'includes/lang/en/funzioni.php',
'includes/lang/en/gestione_utenti.php',
'includes/lang/en/giorni_mesi.php',
'includes/lang/en/head.php',
'includes/lang/en/inizio.php',
'includes/lang/en/interconnessioni.php',
'includes/lang/en/inventario.php',
'includes/lang/en/lista_citta.php',
'includes/lang/en/lista_documentiid.php',
'includes/lang/en/lista_nazioni.php',
'includes/lang/en/lista_parentele.php',
'includes/lang/en/lista_regioni.php',
'includes/lang/en/l_n',
'includes/lang/en/messaggi.php',
'includes/lang/en/modifica_app.php',
'includes/lang/en/modifica_cliente.php',
'includes/lang/en/modifica_contratto.php',
'includes/lang/en/modifica_costi.php',
'includes/lang/en/modifica_ospiti.php',
'includes/lang/en/modifica_prenota.php',
'includes/lang/en/modifica_var_contr.php',
'includes/lang/en/ordine_frasi.php',
'includes/lang/en/personalizza.php',
'includes/lang/en/hoteld_doc_backup.php',
'includes/lang/en/prenota.php',
'includes/lang/en/privilegi_utenti.php',
'includes/lang/en/punto_vendita.php',
'includes/lang/en/storia_soldi.php',
'includes/lang/en/tabella2.php',
'includes/lang/en/tabella3.php',
'includes/lang/en/tabella.php',
'includes/lang/en/tab_tariffe.php',
'includes/lang/en/unit.php',
'includes/lang/en/visualizza_contratto.php',
'includes/lang/en/visualizza_contratto_var.php',
'includes/lang/en/visualizza_tabelle.php',
'includes/lang/es/',
'includes/lang/es/aggiorna.php',
'includes/lang/es/clienti.php',
'includes/lang/es/costi.php',
'includes/lang/es/crea_backup.php',
'includes/lang/es/creadb.php',
'includes/lang/es/crea_modelli.php',
'includes/lang/es/creaprezzi.php',
'includes/lang/es/crearegole.php',
'includes/lang/es/disponibilita.php',
'includes/lang/es/foot.php',
'includes/lang/es/funzioni.php',
'includes/lang/es/gestione_utenti.php',
'includes/lang/es/giorni_mesi.php',
'includes/lang/es/head.php',
'includes/lang/es/inizio.php',
'includes/lang/es/interconnessioni.php',
'includes/lang/es/inventario.php',
'includes/lang/es/lista_citta.php',
'includes/lang/es/lista_documentiid.php',
'includes/lang/es/lista_nazioni.php',
'includes/lang/es/lista_parentele.php',
'includes/lang/es/lista_regioni.php',
'includes/lang/es/l_n',
'includes/lang/es/messaggi.php',
'includes/lang/es/modifica_app.php',
'includes/lang/es/modifica_cliente.php',
'includes/lang/es/modifica_contratto.php',
'includes/lang/es/modifica_costi.php',
'includes/lang/es/modifica_ospiti.php',
'includes/lang/es/modifica_prenota.php',
'includes/lang/es/modifica_var_contr.php',
'includes/lang/es/ordine_frasi.php',
'includes/lang/es/personalizza.php',
'includes/lang/es/hoteld_doc_backup.php',
'includes/lang/es/prenota.php',
'includes/lang/es/privilegi_utenti.php',
'includes/lang/es/punto_vendita.php',
'includes/lang/es/storia_soldi.php',
'includes/lang/es/tabella2.php',
'includes/lang/es/tabella3.php',
'includes/lang/es/tabella.php',
'includes/lang/es/tab_tariffe.php',
'includes/lang/es/unit.php',
'includes/lang/es/visualizza_contratto.php',
'includes/lang/es/visualizza_contratto_var.php',
'includes/lang/es/visualizza_tabelle.php',
'includes/templates/',
'includes/templates/frasi_mod_disp.php',
'includes/templates/funzioni_mod_disp.php',
'includes/templates/funzioni_modelli.php',
'includes/templates/modello_disponibilita.php',
'includes/templates/temi_mod_disp.php',
'includes/templates/cal/',
'includes/templates/cal/form.php',
'includes/templates/cal/functions.php',
'includes/templates/cal/name.php',
'includes/templates/cal/phrases.php',
'includes/templates/cal/template.php',
'includes/templates/cal/themes.php',
'includes/templates/rat/',
'includes/templates/rat/form.php',
'includes/templates/rat/functions.php',
'includes/templates/rat/name.php',
'includes/templates/rat/phrases.php',
'includes/templates/rat/template.php',
'includes/templates/rat/themes.php',
'includes/unit.php',
'themes/',
'themes/sim/',
'themes/sim/img/',
'themes/sim/img/bar_bg_bot.png',
'themes/sim/img/bar_bg_top.png',
'themes/sim/img/calpick.png',
'themes/sim/inc/',
'themes/sim/inc/functions.js',
'themes/sim/inc/mobile.css',
'themes/sim/inc/paper.css',
'themes/sim/inc/screen.css',
'themes/sim/inc/stylesheet.css',
'themes/sim/php/',
'themes/sim/php/foot.php',
'themes/sim/php/head.php',
'themes/sim/php/.htaccess',
'themes/sim/php/menu.php',
'themes/sim/php/name.php',
'themes/sim/php/selectperiod.php',
'themes/snj/',
'themes/snj/img/',
'themes/snj/img/bar_bg_bot.png',
'themes/snj/img/bar_bg_top.png',
'themes/snj/php/',
'themes/snj/php/foot.php',
'themes/snj/php/head.php',
'themes/snj/php/.htaccess',
'themes/snj/php/menu.php',
'themes/snj/php/name.php',
'themes/snj/php/selectperiod.php'
);



?>